##  Filtering and Searching Discovered SaaS Items
The filter function in the inbox allows you to narrow down the list of items and helps you focus on relevant items based on specific criteria, such as integration source, priority, or other key attributes. For instance, some of the parameters include:
  * Status: Filter the list based on discovered application status - linked, not linked, or rejected.
  * Integration: If you have multiple integrations configured, you can narrow down the discovered items based on one or multiple integrations.
  * Priority: Filter based on the priority level of the application.
  * Action by: Filter the list of applications based on particular users or the system who linked the discovered items to fact sheets.
  * Many other parameters are available based on the integration you're using to discover SaaS. These may include:
    * Usage adoption metrics: Such as total active users, generated traffic, and more.
    * Security-related metrics: Such as application risk index, revised total security scores, and more.


Many of these parameters also allow you to set ranges for more precise filtering.
![Filtering Discovered SaaS Applications](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27475eaf7a441014a5e1bd6d39d40b88_LowRes.png)
Filtering Discovered SaaS Applications
You can search for specific items from a large set of discovered SaaS applications using the search field. For example, you can search by name, external ID, Application ID, and more.
YesNo
Send
